
===========
Core Layers
===========

.. automodule:: npdl.layers.core

.. currentmodule:: npdl.layers

.. autoclass:: Linear
   :members:

.. autoclass:: Dense
   :members:

.. autoclass:: Softmax
   :members:

.. autoclass:: Dropout
   :members:


